==> qtsmbstatus_2.0.4.orig.tar.gz: qtsmbstatus-2.0.4/client/tr/qtsmbstatus_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fr_FR">
<defaultcodec></defaultcodec>
<context>
    <name>ClientSSL</name>
    <message>
        <location filename="../clientssl.cpp" line="248"/>
        <source>Connected to host</source>
        <translation>Ansluten till värd</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="264"/>
        <source>Socket error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="277"/>
        <source>Connection closed</source>
        <translation>Anslutning stängd</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="143"/>
        <source>Host not found !</source>
        <translation>Värden hittades inte!</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="118"/>
        <source>Connection in progress on %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClientSocket</name>
    <message>
        <location filename="../clientsocket.cpp" line="434"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="408"/>
        <source>Send out message to all users</source>
        <translation>Skicka ut medelande till alla användare</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="418"/>
        <source>Send out message to</source>
        <translation>Skicka ut medelande till</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="428"/>
        <source>Disconnect user</source>
        <translation>Koppla ner användaren</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="499"/>
        <source>Message to send</source>
        <translation>Medelande att skicka</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="527"/>
        <source>Message to send to %1:</source>
        <translation>Medelande att skicka till %1:</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="561"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Vill du verkligen koppla ner användare %1?</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="153"/>
        <source>Host not found !</source>
        <translation>Värden hittades inte!</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <location filename="../log.cpp" line="80"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="80"/>
        <source>Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.cpp" line="80"/>
        <source>User</source>
        <translation>Användare</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="80"/>
        <source>Service</source>
        <translation>Tjänst</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="106"/>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="80"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <location filename="../configure.ui" line="13"/>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="251"/>
        <source>Autoconnect</source>
        <translation>Auto anslut</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="258"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="235"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="281"/>
        <source>Host Address</source>
        <translation>Värdadress</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="178"/>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="327"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="320"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="271"/>
        <source>Username (default :  username = root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="108"/>
        <source>Log SMB/CIFS activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="98"/>
        <source>Status notification messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="25"/>
        <source>Notifications and log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="43"/>
        <source>Limit log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="72"/>
        <source>days</source>
        <translation>dagar</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="88"/>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="147"/>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="191"/>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="204"/>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="207"/>
        <source>Show hidden shares</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="217"/>
        <source>Connection</source>
        <translation>Anslutning</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="248"/>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="95"/>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <location filename="../form_smbstatus.ui" line="13"/>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="174"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="194"/>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Om QrSmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="211"/>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="41"/>
        <source>Connect/Disconnect</source>
        <translation>Anslut/Koppla ner</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="65"/>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="228"/>
        <source>&amp;Configure client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="161"/>
        <source>&amp;Search</source>
        <translation>&amp;Sök</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="239"/>
        <source>&amp;Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="250"/>
        <source>&amp;User</source>
        <translation>&amp;Användare</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="261"/>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="272"/>
        <source>&amp;Locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="283"/>
        <source>&amp;Next</source>
        <translation>&amp;Nästa</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="289"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="297"/>
        <source>&amp;Find text</source>
        <translation>&amp;Sök text</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="303"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="150"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="214"/>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="231"/>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="242"/>
        <source>Search machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="253"/>
        <source>Search user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="264"/>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="275"/>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="286"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="300"/>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="311"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avsluta</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="314"/>
        <source>Quit QtSmbstatus</source>
        <translation>Avsluta QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="327"/>
        <source>Co&amp;nnect</source>
        <translation>A&amp;nslut</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="319"/>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="197"/>
        <source>About QtSmbstatus</source>
        <translation>Om QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <location filename="../log.ui" line="13"/>
        <source>View Activities</source>
        <translation>Visa aktiviteter</translation>
    </message>
    <message>
        <location filename="../log.ui" line="124"/>
        <source>View/hide shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.ui" line="156"/>
        <source>View/hide files</source>
        <translation>Visa/Göm filer</translation>
    </message>
    <message>
        <location filename="../log.ui" line="196"/>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.ui" line="41"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../log.ui" line="104"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../log.ui" line="70"/>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <location filename="../login_dialog.ui" line="84"/>
        <source>login</source>
        <translation>logga in</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="115"/>
        <source>exit</source>
        <translation>avsluta</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="52"/>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="132"/>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="162"/>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="19"/>
        <source>Connect to qtsmbstatus server</source>
        <translation>Anslut till qtsmbstatus server</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <location filename="../main_windows.cpp" line="416"/>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="486"/>
        <source>Search share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="495"/>
        <source>Search locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="651"/>
        <source>Text not found.</source>
        <translation>Texten hittades inte.</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="62"/>
        <source>QtSmbstatus Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="363"/>
        <source>Connect</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="152"/>
        <source>Minimize</source>
        <translation>Minimera</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="74"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="150"/>
        <source>Restore</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="343"/>
        <source>Disconnect</source>
        <translation>Koppla ner</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="737"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="738"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="67"/>
        <source>Show CIFS/SMB activities</source>
        <translation>Visa CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="83"/>
        <source>Impossible to know samba version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="394"/>
        <source>Invalid login or password !</source>
        <translation>Ogiltigt användarnamn eller lösenord!</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="749"/>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="405"/>
        <source>Thanks to:</source>
        <translation>Tack till:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="69"/>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="456"/>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="467"/>
        <source>Search machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="477"/>
        <source>Search user</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qtsmbstatus_2.1.3.orig.tar.gz: qtsmbstatus-2.1.3/client/tr/qtsmbstatus_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sv">
<context>
    <name>LogForm</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation>Användare</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Tjänst</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Öppna fil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <source>Show CIFS/SMB activities</source>
        <translation>Visa CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Minimera</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Thanks to:</source>
        <translation>Tack till:</translation>
    </message>
    <message>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <source>Text not found.</source>
        <translation>Texten hittades inte.</translation>
    </message>
    <message>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB aktiviteter</translation>
    </message>
    <message>
        <source>Message to send</source>
        <translation>Medelande att skicka</translation>
    </message>
    <message>
        <source>Message to send to %1:</source>
        <translation>Medelande att skicka till %1:</translation>
    </message>
    <message>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Vill du verkligen koppla ner användare %1?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ja</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Nej</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <source>Send out message to all users</source>
        <translation>Skicka ut medelande till alla användare</translation>
    </message>
    <message>
        <source>Send out message to</source>
        <translation>Skicka ut medelande till</translation>
    </message>
    <message>
        <source>Disconnect user</source>
        <translation>Koppla ner användaren</translation>
    </message>
    <message>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Configure</source>
        <translation>Konfigurera</translation>
    </message>
    <message>
        <source>Autoconnect</source>
        <translation>Auto anslut</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host Address</source>
        <translation>Värdadress</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Username (default :  username = root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log SMB/CIFS activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status notification messages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications and log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>days</source>
        <translation>dagar</translation>
    </message>
    <message>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares (share$)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show hidden shares</source>
        <translation></translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Anslutning</translation>
    </message>
    <message>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;Om QrSmbstatus</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om &amp;Qt</translation>
    </message>
    <message>
        <source>Connect/Disconnect</source>
        <translation>Anslut/Koppla ner</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <source>&amp;Configure client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Sök</translation>
    </message>
    <message>
        <source>&amp;Machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;User</source>
        <translation>&amp;Användare</translation>
    </message>
    <message>
        <source>Share &amp;open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Locked file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Nästa</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <translation>&amp;Sök text</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <source>Configure QtSmbstatus client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search machine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search share open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search file open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <source>Find text</source>
        <translation>Sök text</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Avsluta</translation>
    </message>
    <message>
        <source>Quit QtSmbstatus</source>
        <translation>Avsluta QtSmbstatus</translation>
    </message>
    <message>
        <source>Co&amp;nnect</source>
        <translation>A&amp;nslut</translation>
    </message>
    <message>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About QtSmbstatus</source>
        <translation>Om QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <source>View Activities</source>
        <translation>Visa aktiviteter</translation>
    </message>
    <message>
        <source>View/hide shares</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View/hide files</source>
        <translation>Visa/Göm filer</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Save log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <source>login</source>
        <translation>logga in</translation>
    </message>
    <message>
        <source>exit</source>
        <translation>avsluta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Connect to qtsmbstatus server</source>
        <translation>Anslut till qtsmbstatus server</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <source>Connect</source>
        <translation>Anslut</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Koppla ner</translation>
    </message>
    <message>
        <source>Invalid login or password !</source>
        <translation>Ogiltigt användarnamn eller lösenord!</translation>
    </message>
    <message>
        <source>Connection in progress on %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Ansluten till värd</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Anslutning stängd</translation>
    </message>
</context>
</TS>
